"""
Path: photon_geocoder/config.py

Configuration file for the geocoder.

This file contains the configuration for the geocoder. It is used to define the
default values for the geocoder and to define the OSM tags that can be used
when querying the Photon API.
"""

OSM_TAGS = {
    'access': {'yes', 'no', 'permissive', 'private', 'customers', 'destination'},
    'amenity': {'vending_machine', 'kindergarten', 'bicycle_parking', 'waste_disposal', 'fuel', 'bar', 'post_box', 'toilets', 'atm', 'pharmacy', 'restaurant', 'post_office', 'drinking_water', 'waste_basket', 'shelter', 'recycling', 'parking_space', 'hunting_stand', 'fast_food', 'bench', 'place_of_worship', 'bank', 'cafe', 'school', 'hospital', 'parking'},
    'area': {'yes'},
    'backrest': {'no', 'yes'},
    'barrier': {'fence', 'wall', 'bollard', 'hedge', 'lift_gate', 'kerb', 'gate', 'retaining_wall'},
    'bench': {'no', 'yes'}, 'bicycle': {'use_sidepath', 'no', 'yes', 'designated'},
    'bicycle_parking': {'stands'}, 'bin': {'no', 'yes'},
    'boat': {'no'}, 'boundary': {'administrative'},
    'bridge': {'yes'},
    'building': {'static_caravan', 'hut', 'garage', 'bungalow', 'outbuilding', 'greenhouse', 'carport', 'roof', 'construction', 'garages', 'shed', 'farm_auxiliary', 'terrace', 'barn', 'commercial', 'allotment_house', 'detached', 'cabin', 'yes', 'apartments', 'house', 'retail', 'residential', 'industrial', 'semidetached_house', 'warehouse', 'office', 'service', 'ruins', 'school', 'church', 'farm'},
    'bus': {'yes'},
    'circuits': {'1'},
    'construction': {'yes'},
    'covered': {'no', 'yes'},
    'crossing': {'uncontrolled', 'zebra', 'marked', 'unmarked', 'traffic_signals'},
    'cycleway': {'no', 'lane'},
    'denomination': {'catholic'},
    'direction': {'forward', 'backward'},
    'electrified': {'no', 'contact_line'},
    'embankment': {'yes'},
    'emergency': {'fire_hydrant'},
    'entrance': {'staircase', 'yes', 'main'},
    'fee': {'no', 'yes'},
    'foot': {'use_sidepath', 'no', 'designated', 'yes'},
    'footway': {'sidewalk', 'crossing'},
    'golf': {'fairway', 'bunker', 'green', 'tee', 'hole'},
    'healthcare': {'pharmacy'},
    'highway': {'unclassified', 'steps', 'motorway_junction', 'trunk', 'construction', 'traffic_signals', 'tertiary_link', 'tertiary', 'crossing', 'track', 'primary', 'street_lamp', 'secondary', 'motorway', 'path', 'cycleway', 'motorway_link', 'stop', 'residential', 'secondary_link', 'service', 'pedestrian', 'trunk_link', 'milestone', 'primary_link', 'bus_stop', 'give_way', 'living_street', 'footway', 'turning_circle'},
    'hiking': {'yes'},
    'historic': {'memorial'},
    'horse': {'no', 'yes'},
    'indoor': {'yes'},
    'informal': {'yes'},
    'junction': {'roundabout'},
    'landcover': {'trees'},
    'landuse': {'industrial', 'commercial', 'orchard', 'allotments', 'grass', 'farmyard', 'basin', 'meadow', 'reservoir', 'farmland', 'cemetery', 'vineyard', 'retail', 'construction', 'residential', 'forest', 'quarry'},
    'lanes': {'3', '4', '5', '1', '2'},
    'layer': {'1', '-1'},
    'leisure': {'garden', 'picnic_table', 'playground', 'pitch', 'park', 'sports_centre', 'swimming_pool'},
    'level': {'1', '0'},
    'living_street': {'yes'},
    'location': {'surface', 'underground', 'outdoor', 'roof', 'overground'},
    'man_made': {'utility_pole', 'surveillance', 'survey_point', 'bridge', 'works', 'storage_tank', 'mast', 'embankment', 'manhole', 'pipeline', 'tower', 'pier', 'silo', 'petroleum_well', 'cutline'},
    'maxspeed': {'30 mph', '120', '80', '90', '45 mph', '70', '40', '60', '35 mph', '30', '25 mph', '20 mph', '50', '20', '40 mph', '100'},
    'motor_vehicle': {'private', 'no', 'yes'},
    'motorcar': {'no'},
    'motorcycle': {'yes'},
    'natural': {'scrub', 'wetland', 'wood', 'tree_row', 'cliff', 'scree', 'tree', 'coastline', 'bare_rock', 'heath', 'sand', 'grassland', 'peak', 'rock', 'water'},
    'noexit': {'yes'},
    'noname': {'yes'},
    'office': {'government', 'company'},
    'oneway': {'no', 'yes'},
    'outdoor_seating': {'yes'},
    'parking': {'street_side', 'surface'},
    'parking_space': {'normal'},
    'place': {'village', 'plot', 'islet', 'hamlet', 'farm', 'neighbourhood', 'locality', 'isolated_dwelling'},
    'power': {'line', 'pole', 'generator', 'tower', 'substation', 'minor_line'},
    'public_transport': {'stop_area', 'stop_position', 'platform'},
    'railway': {'level_crossing', 'buffer_stop', 'switch', 'rail', 'abandoned', 'signal'},
    'ramp': {'no'},
    'recycling_type': {'container'},
    'religion': {'christian', 'muslim'},
    'residential': {'rural'},
    'restriction': {'no_u_turn', 'no_left_turn', 'only_straight_on'},
    'route': {'bus', 'road', 'hiking'},
    'seasonal': {'yes'},
    'service': {'siding', 'spur', 'driveway', 'drive-through', 'yard', 'parking_aisle', 'alley'},
    'shelter': {'no', 'yes'},
    'shop': {'bakery', 'hairdresser', 'convenience', 'supermarket', 'car_repair', 'clothes'},
    'shoulder': {'no'},
    'sidewalk': {'right', 'both', 'left', 'no', 'separate'},
    'smoothness': {'intermediate', 'good', 'bad', 'very_bad', 'excellent'},
    'sport': {'basketball', 'soccer', 'tennis'},
    'structure': {'lattice'},
    'supervised': {'no'},
    'surface': {'wood', 'asphalt', 'dirt', 'fine_gravel', 'ground', 'paving_stones', 'grass', 'paved', 'sand', 'sett', 'unpaved', 'compacted', 'gravel', 'concrete'},
    'takeaway': {'yes'},
    'toll': {'yes'},
    'tourism': {'viewpoint', 'hotel', 'artwork', 'information', 'attraction'},
    'train': {'yes'},
    'type': {'multipolygon', 'public_transport', 'restriction', 'boundary', 'route', 'associatedStreet'},
    'wall': {'dry_stone', 'no'},
    'water': {'river', 'lake', 'reservoir', 'basin', 'pond'},
    'waterway': {'river', 'dam', 'canal', 'stream', 'ditch', 'drain'},
    'wheelchair': {'no', 'yes', 'limited'}
}
